==> jest-react-redux-1.0.0.tgz: package/README.md <==
# jest-react-redux

[![Powered by Immowelt](https://img.shields.io/badge/powered%20by-immowelt-yellow.svg?colorB=ffb200)](https://stackshare.io/immowelt-group/)
[![Greenkeeper badge](https://badges.greenkeeper.io/ImmoweltGroup/jest-react-redux.svg)](https://greenkeeper.io/)
[![Build Status](https://travis-ci.org/ImmoweltGroup/jest-react-redux.svg?branch=master)](https://travis-ci.org/ImmoweltGroup/jest-react-redux)
[![Dependency Status](https://david-dm.org/ImmoweltGroup/jest-react-redux.svg)](https://david-dm.org/ImmoweltGroup/jest-react-redux)
[![devDependency Status](https://david-dm.org/ImmoweltGroup/jest-react-redux/dev-status.svg)](https://david-dm.org/ImmoweltGroup/jest-react-redux#info=devDependencies&view=table)
[![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/semantic-release/semantic-release)

> Makes snapshot testing of react-redux (e.g. mapStateToProps or mapDispatchToProps) glue-code easy as pie.

## Installation
To install the stable version:

```sh
# Using npm
npm install --save-dev jest-react-redux

# or using yarn
yarn add --dev jest-react-redux
```

## Features
* Automatically mocks impure function usages (selectors) within `mapStateToProps`.
* Creates easily readable results which you can use with Jests snapshot feature.
* Creates less headaches while writing good tests for your `react-redux` glue-code.

## Documentation
* [Introduction](/docs/introduction/README.md)
* [API](/docs/api/README.md)
* [FAQ](/docs/api/FAQ.md)

## Contributing
See the `CONTRIBUTING.md` file at the root of the repository.

## Licensing
See the `LICENSE` file at the root of the repository.

==> jest-react-redux-1.0.1.tgz: package/README.md <==
# jest-react-redux

[![Powered by Immowelt](https://img.shields.io/badge/powered%20by-immowelt-yellow.svg?colorB=ffb200)](https://stackshare.io/immowelt-group/)
[![Greenkeeper badge](https://badges.greenkeeper.io/ImmoweltGroup/jest-react-redux.svg)](https://greenkeeper.io/)
[![Build Status](https://travis-ci.org/ImmoweltGroup/jest-react-redux.svg?branch=master)](https://travis-ci.org/ImmoweltGroup/jest-react-redux)
[![Dependency Status](https://david-dm.org/ImmoweltGroup/jest-react-redux.svg)](https://david-dm.org/ImmoweltGroup/jest-react-redux)
[![devDependency Status](https://david-dm.org/ImmoweltGroup/jest-react-redux/dev-status.svg)](https://david-dm.org/ImmoweltGroup/jest-react-redux#info=devDependencies&view=table)
[![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/semantic-release/semantic-release)

> Makes snapshot testing of react-redux (e.g. mapStateToProps or mapDispatchToProps) glue-code easy as pie.

## Installation
To install the latest stable version:

```sh
# Using npm
npm install --save-dev jest-react-redux

# or using yarn
yarn add --dev jest-react-redux
```

## Features
* Automatically mocks impure function usages (selectors) within `mapStateToProps`.
* Creates easily readable results which you can use with Jests snapshot feature.
* Creates less headaches while writing good tests for your `react-redux` glue-code.

## Documentation
* [Introduction](/docs/introduction/README.md)
* [API](/docs/api/README.md)
* [FAQ](/docs/api/FAQ.md)

## Contributing
See the `CONTRIBUTING.md` file at the root of the repository.

## Licensing
See the `LICENSE` file at the root of the repository.
